@@ -11,11 +11,8 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Browser UI code.
 """
-$Id: __init__.py 70825 2006-10-20 01:34:05Z rogerineichen $
-"""
-__docformat__ = 'reStructuredText'
-
 import zope.component
 import zope.interface
 import zope.location
@@ -28,9 +25,9 @@ from zope.traversing.interfaces import IContainmentRoot
 from z3c.breadcrumb import interfaces
 
 
+@zope.interface.implementer(interfaces.IBreadcrumbs)
 class Breadcrumbs(zope.location.Location):
     """Breadcrumbs implementation using IBreadcrumb adapters."""
-    zope.interface.implements(interfaces.IBreadcrumbs)
     zope.component.adapts(zope.interface.Interface, IHTTPRequest)
 
     def __init__(self, context, request):
@@ -51,8 +48,8 @@ class Breadcrumbs(zope.location.Location):
         request = self.request
 
         objects = []
-        for obj in ( [self.context] +
-                     list(zope.traversing.api.getParents(self.context)) ):
+        for obj in ([self.context] +
+                    list(zope.traversing.api.getParents(self.context))):
             objects.append(obj)
             if sameProxiedObjects(obj, request.getVirtualHostRoot()) or \
                     isinstance(obj, Exception):
@@ -69,9 +66,9 @@ class Breadcrumbs(zope.location.Location):
                    'activeURL': info.activeURL}
 
 
-class GenericBreadcrumb(object):
+@zope.interface.implementer(interfaces.IBreadcrumb)
+class GenericBreadcrumb:
     """A generic breadcrumb adapter."""
-    zope.interface.implements(interfaces.IBreadcrumb)
     zope.component.adapts(zope.interface.Interface, IHTTPRequest)
 
     # See interfaces.IBreadcrumb
@@ -98,5 +95,5 @@ class GenericBreadcrumb(object):
 
 
 def CustomNameBreadcrumb(name):
-    return type('CustomNameBreadcrumb(%r)' %name,
+    return type('CustomNameBreadcrumb(%r)' % name,
                 (GenericBreadcrumb,), {'name': name})
