@@ -11,12 +11,17 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-from zope.app.testing import setup
-from zope.interface.verify import verifyObject
-from zope.publisher.browser import TestRequest
+"""Tests
+"""
 import doctest
 import unittest
 
+import zope.location
+import zope.site.testing
+import zope.traversing.testing
+from zope.interface.verify import verifyObject
+from zope.publisher.browser import TestRequest
+
 
 def doctest_Breadcrumbs_interface():
     """Test that Breadcrumbs matches the interface
@@ -41,19 +46,20 @@ def doctest_GenericBreadcrumb_interface():
 
 
 def setUp(test):
-    site = setup.placefulSetUp(site=True)
+    site = zope.site.testing.siteSetUp(True)
+    zope.traversing.testing.setUp()
     test.globs['rootFolder'] = site
 
+
 def tearDown(test):
-    setup.placefulTearDown()
+    zope.site.testing.siteTearDown()
 
 
 def test_suite():
     return unittest.TestSuite([
-            doctest.DocFileSuite(
-                'README.txt',
-                setUp=setUp, tearDown=tearDown,
-                optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS),
-            doctest.DocTestSuite(
-                setUp=setUp, tearDown=tearDown),
-            ])
+        doctest.DocFileSuite(
+            'README.txt',
+            setUp=setUp, tearDown=tearDown,
+            optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),
+        doctest.DocTestSuite(setUp=setUp, tearDown=tearDown),
+    ])
